string._TemplateMetaclass

string :: _TemplateMetaclass :: Class _TemplateMetaclass |
[hide private]
[frames] | no frames]

# Type _TemplateMetaclass

    object --+
             |
          type --+
                 |
                _TemplateMetaclass

Instance Methods | [hide private]
the object's type |
__init__(cls, name, bases, dct) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
Inherited from `type`: `__call__`, `__delattr__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__hash__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__format__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| pattern = ``'``\n %(delim)s(?:\n (?P<escaped>%(delim)s) |` `...``

Properties | [hide private]
Inherited from `type`: `__abstractmethods__`, `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__instancecheck__`, `__itemsize__`, `__mro__`, `__name__`, `__subclasscheck__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(cls, name, bases, dct) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Returns: the object's type Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### pattern Value:
      '''
          %(delim)s(?:
            (?P<escaped>%(delim)s) |   # Escape sequence of two delimiters
            (?P<named>%(id)s)      |   # delimiter and a Python identifier
            {(?P<braced>%(id)s)}   |   # delimiter and a braced identifier
            (?P<invalid>)              # Other ill-formed delimiter exprs
          )
          '''